geowatch.cli.experimental.fixup\_predict\_kwcoco\_metadata module
=================================================================

.. automodule:: geowatch.cli.experimental.fixup_predict_kwcoco_metadata
   :members:
   :undoc-members:
   :show-inheritance:
